# Generated by roxygen2: do not edit by hand

export(Fpsn)
export(PSSeg)
export(anotherBkp)
export(binMissingValues)
export(defaultWeights)
export(doCBS)
export(doDynamicProgramming)
export(doGFLars)
export(doPSCBS)
export(doPSCN)
export(doRBS)
export(estimateSd)
export(getCopyNumberDataByResampling)
export(getTpFp)
export(jointSeg)
export(leftMultiplyByInvXAtXA)
export(leftMultiplyByXt)
export(modelSelection)
export(multiplyXtXBySparse)
export(oneBkp)
export(plotSeg)
export(pruneByDP)
export(randomProfile)
export(segmentByGFLars)
export(segmentByRBS)
importFrom(acnr,listDataSets)
importFrom(acnr,loadCnRegionData)
importFrom(matrixStats,binMeans)
useDynLib(jointseg)
